aboutsummaryrefslogtreecommitdiff
path: root/libcrystfel/src/reflist.c
diff options
context:
space:
mode:
authorThomas White <taw@physics.org>2020-05-27 14:00:17 +0200
committerThomas White <taw@physics.org>2020-07-29 18:42:57 +0200
commitc03c4aa196d68e408abef9f66ad3f3e30b8a16ac (patch)
treeaf1058d405e3a4cff8941d0970c4e493471ece0a /libcrystfel/src/reflist.c
parent0f5bec373a232dfd935fa3a7cc61759f67f1b2ce (diff)
Convert prediction and integration to detgeom
Diffstat (limited to 'libcrystfel/src/reflist.c')
-rw-r--r--libcrystfel/src/reflist.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/libcrystfel/src/reflist.c b/libcrystfel/src/reflist.c
index 9cedfc86..df8f24fc 100644
--- a/libcrystfel/src/reflist.c
+++ b/libcrystfel/src/reflist.c
@@ -53,7 +53,7 @@ struct _refldata {
/* Location in image */
double fs;
double ss;
- struct panel *panel;
+ int panel_number;
/* Non-zero if this reflection can be used for scaling */
int scalable;
@@ -308,12 +308,13 @@ void get_detector_pos(const Reflection *refl, double *fs, double *ss)
/**
* \param refl: Reflection
*
- * \returns the panel which the reflection appears on
+ * \returns panel number (index in detgeom/DataTemplate structure)
+ * which the reflection appears on
*
**/
-struct panel *get_panel(const Reflection *refl)
+int get_panel_number(const Reflection *refl)
{
- return refl->data.panel;
+ return refl->data.panel_number;
}
@@ -589,14 +590,13 @@ void set_detector_pos(Reflection *refl, double fs, double ss)
/**
* \param refl: Reflection
* \param p: Pointer to the panel structure on which the reflection appears
*
* Note that the pointer will be stored, not the contents of the structure.
*
**/
-void set_panel(Reflection *refl, struct panel *p)
+void set_panel_number(Reflection *refl, int pn)
{
- refl->data.panel = p;
+ refl->data.panel_number = pn;
}
@@ -589,14 +590,13 @@ void set_detector_pos(Reflection *refl, double fs, double ss)
/**
* \param refl: Reflection
- * \param p: Pointer to the panel structure on which the reflection appears
- *
- * Note that the pointer will be stored, not the contents of the structure.
+ * \param pn: Panel number (index in detgeom/DataTemplate structure) of
+ * the panel on which the reflection appears.
*
**/